@@ -128,6 +128,13 @@ void IDirectFBDisplayLayer::SetScreenRectangle (int x,
      DFBCHECK( iface->SetScreenRectangle (iface, x, y, width, height) );
 }
 
+void IDirectFBDisplayLayer::SetClipRegions (const DFBRegion *regions,
+                                            int              num_regions,
+                                            DFBBoolean       positive)
+{
+     DFBCHECK( iface->SetClipRegions (iface, regions, num_regions, positive) );
+}
+
 void IDirectFBDisplayLayer::SetSrcColorKey (__u8 r, __u8 g, __u8 b)
 {
      DFBCHECK( iface->SetSrcColorKey (iface, r, g, b) );
@@ -268,3 +275,9 @@ void IDirectFBDisplayLayer::GetSourceDescriptions (DFBDisplayLayerSourceDescript
 {
      DFBCHECK( iface->GetSourceDescriptions (iface, descriptions) );
 }
+
+void IDirectFBDisplayLayer::SwitchContext (DFBBoolean exclusive)
+{
+     DFBCHECK( iface->SwitchContext (iface, exclusive) );
+}
+
