@@ -59,6 +59,13 @@ public:
      
      void                         SendEvent             (DFBEvent              *evt);
 
+     void                         SetPlaybackFlags      (DFBVideoProviderPlaybackFlags flags);
+
+     void                         SetSpeed              (double                 multiplier);
+     double                       GetSpeed              ();
+
+     void                         SetVolume             (float                  level);
+     float                        GetVolume             ();
 
 protected:
      IDirectFBVideoProvider(IDirectFBVideoProvider_C *idirectfbvideoprovider);
